interface ip_intf #(
    parameter DATA_WIDTH = 8,
    parameter KEEP_WIDTH = (DATA_WIDTH/8),
    parameter ID_WIDTH = 8,
    parameter DEST_WIDTH = 8,
    parameter USER_WIDTH = 1
);

    logic                          ip_hdr_valid;
    logic                          ip_hdr_ready;
    logic [47:0]                   eth_dest_mac;
    logic [47:0]                   eth_src_mac;
    logic [15:0]                   eth_type;
    logic [3:0]                    ip_version;
    logic [3:0]                    ip_ihl;
    logic [5:0]                    ip_dscp;
    logic [1:0]                    ip_ecn;
    logic [15:0]                   ip_length;
    logic [15:0]                   ip_identification;
    logic [2:0]                    ip_flags;
    logic [12:0]                   ip_fragment_offset;
    logic [7:0]                    ip_ttl;
    logic [7:0]                    ip_protocol;
    logic [15:0]                   ip_header_checksum;
    logic [31:0]                   ip_source_ip;
    logic [31:0]                   ip_dest_ip;
    logic [DATA_WIDTH-1:0]         ip_payload_axis_tdata;
    logic [KEEP_WIDTH-1:0]         ip_payload_axis_tkeep;
    logic                          ip_payload_axis_tvalid;
    logic                          ip_payload_axis_tready;
    logic                          ip_payload_axis_tlast;
    logic [ID_WIDTH-1:0]           ip_payload_axis_tid;
    logic [DEST_WIDTH-1:0]         ip_payload_axis_tdest;
    logic [USER_WIDTH-1:0]         ip_payload_axis_tuser;

    modport MASTER (
        output ip_hdr_valid,
        input  ip_hdr_ready,
        output eth_dest_mac,
        output eth_src_mac,
        output eth_type,
        output ip_version,
        output ip_ihl,
        output ip_dscp,
        output ip_ecn,
        output ip_length,
        output ip_identification,
        output ip_flags,
        output ip_fragment_offset,
        output ip_ttl,
        output ip_protocol,
        output ip_header_checksum,
        output ip_source_ip,
        output ip_dest_ip,
        output ip_payload_axis_tdata,
        output ip_payload_axis_tkeep,
        output ip_payload_axis_tvalid,
        input  ip_payload_axis_tready,
        output ip_payload_axis_tlast,
        output ip_payload_axis_tid,
        output ip_payload_axis_tdest,
        output ip_payload_axis_tuser
    );

    modport SLAVE (
        input  ip_hdr_valid,
        output ip_hdr_ready,
        input  eth_dest_mac,
        input  eth_src_mac,
        input  eth_type,
        input  ip_version,
        input  ip_ihl,
        input  ip_dscp,
        input  ip_ecn,
        input  ip_length,
        input  ip_identification,
        input  ip_flags,
        input  ip_fragment_offset,
        input  ip_ttl,
        input  ip_protocol,
        input  ip_header_checksum,
        input  ip_source_ip,
        input  ip_dest_ip,
        input  ip_payload_axis_tdata,
        input  ip_payload_axis_tkeep,
        input  ip_payload_axis_tvalid,
        output ip_payload_axis_tready,
        input  ip_payload_axis_tlast,
        input  ip_payload_axis_tid,
        input  ip_payload_axis_tdest,
        input  ip_payload_axis_tuser
    );

endinterface
